Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: components/mus/ws/window_manager_window_tree_factory_set.h

Issue 2089023002: Promotes remaining global window manager state into WindowManagerState (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: override Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/mus/ws/window_manager_window_tree_factory_set.h
diff --git a/components/mus/ws/window_manager_window_tree_factory_set.h b/components/mus/ws/window_manager_window_tree_factory_set.h
index 5622fe75fb77d2ed3f60a4092f4d28d4af25ad49..a118e6978bcf233dbe23d1b4b706a0fd78101b9f 100644
--- a/components/mus/ws/window_manager_window_tree_factory_set.h
+++ b/components/mus/ws/window_manager_window_tree_factory_set.h
@@ -18,8 +18,8 @@
namespace mus {
namespace ws {
-class GlobalWindowManagerState;
class UserIdTracker;
+class WindowManagerState;
class WindowManagerWindowTreeFactory;
class WindowManagerWindowTreeFactorySetObserver;
class WindowServer;
@@ -47,10 +47,9 @@ class WindowManagerWindowTreeFactorySet : public UserIdTrackerObserver {
const UserId& user_id,
mojo::InterfaceRequest<mojom::WindowManagerWindowTreeFactory> request);
// Returns the GlobalWindowManagerState for the specified user, or null if
// not yet set.
- GlobalWindowManagerState* GetGlobalWindowManagerStateForUser(
- const UserId& user_id);
+ WindowManagerState* GetWindowManagerStateForUser(const UserId& user_id);
// Deletes the WindowManagerWindowTreeFactory associated with |tree|. Does
// nothing if there is no WindowManagerWindowTreeFactory associated with
@@ -74,9 +73,6 @@ class WindowManagerWindowTreeFactorySet : public UserIdTrackerObserver {
WindowManagerWindowTreeFactory* factory);
// UserIdTrackerObserver:
- void OnActiveUserIdChanged(const UserId& previously_active_id,
- const UserId& active_id) override;
- void OnUserIdAdded(const UserId& id) override;
void OnUserIdRemoved(const UserId& id) override;
// Set to true the first time a valid factory has been found.
« no previous file with comments | « components/mus/ws/window_manager_window_tree_factory.cc ('k') | components/mus/ws/window_manager_window_tree_factory_set.cc » ('j') | no next file with comments »
@@ -47,10 +47,9 @@ class WindowManagerWindowTreeFactorySet : public UserIdTrackerObserver {
const UserId& user_id,
mojo::InterfaceRequest<mojom::WindowManagerWindowTreeFactory> request);
- // Returns the GlobalWindowManagerState for the specified user, or null if
+ // Returns the WindowManagerState for the specified user, or null if
// not yet set.

Powered by Google App Engine
This is Rietveld 408576698